@@ -16,8 +16,11 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 import syslog
+import socket
 from __init__ import NAME
 
+FQDN = socket.getfqdn()
+
 
 def logging(priority, message):
     """
